@@ -20,7 +20,7 @@ import string as __string
 import logging as __logging
 import datetime as __datetime
 import configparser as __configparser
-from IPython.core.display import display, HTML
+# from IPython.core.display import display, HTML
 
 # Making local imports
 # import time_format as t
@@ -265,8 +265,8 @@ def return_middle_date(date1, date2):
     return new_date
 
 
-def display_html(rep):
-    display(HTML(rep.text))
+# def display_html(rep):
+#     display(HTML(rep.text))
 
 
 def get_config(config_path):
